#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This work was created by participants in the DataONE project, and is
# jointly copyrighted by participating institutions in DataONE. For
# more information on DataONE, see our web site at http://dataone.org.
#
#   Copyright 2009-2012 DataONE
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

'''
:mod:`svn_checkout`
===================

:Synopsis:
  Subversion checkout of all DataONE componets implemented in Python.

  This script is used instead of a set of "svn externals" properties to avoid
  that a copy of all the Python packages is created when someone checks out the
  trunk.
:Author:
  DataONE (Dahl)
'''

# Stdlib.
import optparse
import os
import re
import sys

# Configuration.
d1_cicore_trunk = 'https://repository.dataone.org/software/cicore/trunk/'

d1_python_components = [
  ('.', 'd1_certificate_python'),
  ('.', 'd1_common_python'),
  ('.', 'd1_libclient_python'),
  ('.', 'd1_schemas'),
  ('.', 'd1_stress_tester'),
  ('.', 'd1_test_utilities_python'),
  ('.', 'd1_x509v3_extractor_python'),
  ('.', 'd1_workspace_client'),

  ('itk', 'd1_client_cli'),
  ('itk', 'd1_client_onedrive'),

  ('mn', 'd1_mn_generic'),
]

def main():
  # Command line opts.
  parser = optparse.OptionParser('usage: %prog [options]')
  parser.add_option('--update', dest='update', action='store_true',
                    default=False, help='Update instead of checkout')
  parser.add_option('--commit', dest='commit', action='store_true',
                    default=False, help='Commit instead of checkout')
  (options, arguments) = parser.parse_args()

  for component in d1_python_components:
    repository = os.path.join(d1_cicore_trunk, component[0], component[1])
    local_path = component[1]
    if options.update:
      run_svn_update(repository, local_path)
    elif options.commit:
      run_svn_commit(repository, local_path)
    else:
      run_svn_checkout(repository, local_path)


def run_svn_checkout(repository, local_path):
  cmd = 'svn co {0} {1}'.format(repository, local_path)
  print cmd
  os.system(cmd)


def run_svn_update(repository, local_path):
  cmd = 'svn up {0} {1}'.format(repository, local_path)
  print cmd
  os.system(cmd)


def run_svn_commit(repository, local_path):
  cmd = 'svn ci {0}'.format(local_path)
  print cmd
  os.system(cmd)


if __name__ == '__main__':
  main()
